/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEpdf 4.1 open source software code, released
 * May 1st, 2009. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2010 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package org.icepdf.ri.viewer;

import org.icepdf.ri.images.Images;

import java.awt.*;
import java.net.URL;

/**
 * <p>This class is the Main class for the ICEpdf Viewer application. It does
 * the following tasks:</p>
 * <ul>
 * <li>Presents a splash window
 * <li>Loads the viewer application
 * </ul>
 *
 * @since 1.0
 */
public class Main {

    private static SplashWindow splashWindow = null;

    public static void main(String[] args) {
        // Read the image data and display the splash screen
        URL imageURL = Images.get("ICEpdf-splashscreen-2009.png");

        if (imageURL != null) {
            Image splashImage =
                    Toolkit.getDefaultToolkit().getImage(imageURL);
            if (splashImage != null) {
                splashWindow = new SplashWindow(splashImage);
                splashWindow.splash();
            }
        }

        // Call the main method of the application's Main class
        // using Reflection so that related classes resoving happens
        // after splash window is shown up
        try {
            Class.forName("org.icepdf.ri.viewer.Launcher")
                    .getMethod("main", String[].class)
                    .invoke(null, new Object[]{args});
        } catch (Throwable e) {
            e.printStackTrace();
            System.err.flush();
            System.exit(10);
        }

        // Dispose the splash screen
        if (splashWindow != null) {
            splashWindow.dispose();
        }
    }
}
